use 5.010001;
use strict;
use warnings;

package Types::Capabilities::CoercedValue::QUEUE;

our $AUTHORITY = 'cpan:TOBYINK';
our $VERSION   = '0.003000';

use parent 'Types::Capabilities::CoercedValue::ARRAYREF';

__PACKAGE__
__END__
